@@ -190,6 +190,14 @@ MOS_STATUS AvcEncodeBRC::Update(void *params)
         "Encode RateControl Method",
         m_rcMode,
         MediaUserSetting::Group::Sequence);
+
+    MediaUserSetting::Value outValue;
+    ReadUserSetting(
+        m_userSettingPtr,
+        outValue,
+        "Adaptive TU Enable",
+        MediaUserSetting::Group::Sequence);
+    m_basicFeature->m_picParam->AdaptiveTUEnabled |= outValue.Get<uint8_t>();
 #endif
     return MOS_STATUS_SUCCESS;
 }
@@ -225,7 +233,7 @@ MOS_STATUS AvcEncodeBRC::AllocateResources()
     allocParamsForBufferLinear.dwBytes = sizeof(VdencBrcPakMmio);
     allocParamsForBufferLinear.pBufName = "VDENC BRC PAK MMIO Buffer";
     allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
-    m_basicFeature->m_recycleBuf->RegisterResource(VdencBrcPakMmioBuffer, allocParamsForBufferLinear, 1);
+    ENCODE_CHK_STATUS_RETURN(m_basicFeature->m_recycleBuf->RegisterResource(VdencBrcPakMmioBuffer, allocParamsForBufferLinear, 1));
 
     // Debug buffer
     allocParamsForBufferLinear.dwBytes  = MOS_ALIGN_CEIL(brcSettings.vdencBrcDbgBufferSize, CODECHAL_PAGE_SIZE);
@@ -266,12 +274,18 @@ MOS_STATUS AvcEncodeBRC::SetDmemForInit(void *params)
     auto avcSeqParams = m_basicFeature->m_seqParam;
     auto avcPicParams = m_basicFeature->m_picParam;
 
+    // VDEnc BRC encodes each field as one frame, so for interlaced we double the
+    //   value of FramesPer100Sec. Otherwise BRC will spend ~2x the requested bits.
+    uint16_t framesFieldsPer100Sec = avcSeqParams->FramesPer100Sec;
+    if (avcPicParams->CurrOriginalPic.PicFlags == PICTURE_TOP_FIELD || avcPicParams->CurrOriginalPic.PicFlags == PICTURE_BOTTOM_FIELD)
+        framesFieldsPer100Sec *= 2;
+
     if (avcSeqParams->FrameSizeTolerance == EFRAMESIZETOL_EXTREMELY_LOW) // Low Delay Mode
     {
         avcSeqParams->MaxBitRate = avcSeqParams->TargetBitRate;
     }
 
-    m_dBrcInitResetInputBitsPerFrame     = avcSeqParams->MaxBitRate * 100.0 / avcSeqParams->FramesPer100Sec;
+    m_dBrcInitResetInputBitsPerFrame     = avcSeqParams->MaxBitRate * 100.0 / framesFieldsPer100Sec;
     m_dBrcInitCurrentTargetBufFullInBits = m_dBrcInitResetInputBitsPerFrame;
     m_dBrcTargetSize                     = avcSeqParams->InitVBVBufferFullnessInBit;
 
@@ -321,7 +335,7 @@ MOS_STATUS AvcEncodeBRC::SetDmemForInit(void *params)
         hucVdencBrcInitDmem->INIT_LowDelayGoldenFrameBoost_U8 = 0; //get from ?
     }
 
-    hucVdencBrcInitDmem->INIT_FrameRateM_U32 = avcSeqParams->FramesPer100Sec;
+    hucVdencBrcInitDmem->INIT_FrameRateM_U32 = framesFieldsPer100Sec;
     hucVdencBrcInitDmem->INIT_FrameRateD_U32 = 100;
 
     hucVdencBrcInitDmem->INIT_ProfileLevelMaxFrame_U32 = m_basicFeature->GetProfileLevelMaxFrameSize();
@@ -338,8 +352,12 @@ MOS_STATUS AvcEncodeBRC::SetDmemForInit(void *params)
         hucVdencBrcInitDmem->INIT_GopP_U16 = intraPeriod / avcSeqParams->GopRefDist;
         hucVdencBrcInitDmem->INIT_GopB_U16 = (avcSeqParams->GopRefDist - 1) * hucVdencBrcInitDmem->INIT_GopP_U16;
 
-        // For now AVC support only GOP4 and GOP8 golden gops
-        if (IsBPyramidWithGoldenBGOP())
+        if (avcSeqParams->GopRefDist >= avcSeqParams->GopPicSize && avcSeqParams->GopPicSize > 1)
+        {
+            hucVdencBrcInitDmem->INIT_ExtGopP_U16 = 1;
+            hucVdencBrcInitDmem->INIT_ExtGopB_U16 = avcSeqParams->GopPicSize - 2;
+        }
+        else if (IsBPyramidWithGoldenBGOP()) // For now AVC support only GOP4 and GOP8 golden gops
         {
             auto    dmem     = hucVdencBrcInitDmem;
             uint8_t BGopSize = (uint8_t)avcSeqParams->GopRefDist;
@@ -379,8 +397,8 @@ MOS_STATUS AvcEncodeBRC::SetDmemForInit(void *params)
     }
 
                                                                              //dynamic deviation thresholds
-    double inputBitsPerFrame = avcSeqParams->MaxBitRate * 100.0 / avcSeqParams->FramesPer100Sec;
-    double bps_ratio = inputBitsPerFrame / (avcSeqParams->VBVBufferSizeInBit * 100.0 / avcSeqParams->FramesPer100Sec/*DEV_STD_FPS*/);
+    double inputBitsPerFrame = avcSeqParams->MaxBitRate * 100.0 / framesFieldsPer100Sec;
+    double bps_ratio = inputBitsPerFrame / (avcSeqParams->VBVBufferSizeInBit * 100.0 / framesFieldsPer100Sec/*DEV_STD_FPS*/);
     if (bps_ratio < VDENC_AVC_BPS_RATIO_LOW) bps_ratio = VDENC_AVC_BPS_RATIO_LOW;
     if (bps_ratio > VDENC_AVC_BPS_RATIO_HIGH) bps_ratio = VDENC_AVC_BPS_RATIO_HIGH;
 
@@ -415,7 +433,7 @@ MOS_STATUS AvcEncodeBRC::SetDmemForInit(void *params)
         }
     }
 
-    hucVdencBrcInitDmem->INIT_InitQPIP = (uint8_t)ComputeBRCInitQP();
+    hucVdencBrcInitDmem->INIT_InitQPIP = (uint8_t)ComputeBRCInitQP(framesFieldsPer100Sec);
 
     // MBBRC control
     if (m_mbBrcEnabled)
@@ -477,8 +495,16 @@ MOS_STATUS AvcEncodeBRC::SetDmemForInit(void *params)
     if (avcSeqParams->FrameSizeTolerance == EFRAMESIZETOL_LOW) // Sliding Window BRC
     {
         hucVdencBrcInitDmem->INIT_SlidingWidowRCEnable_U8 = 1;
-        hucVdencBrcInitDmem->INIT_SlidingWindowSize_U8 = (uint8_t)(avcSeqParams->FramesPer100Sec / 100);
-        hucVdencBrcInitDmem->INIT_SlidingWindowMaxRateRatio_U8 = 120;
+        if (avcSeqParams->RateControlMethod == RATECONTROL_CBR && avcSeqParams->TargetBitRate != 0)
+        {
+            hucVdencBrcInitDmem->INIT_SlidingWindowSize_U8         = MOS_MIN((uint8_t)avcSeqParams->SlidingWindowSize, 60);
+            hucVdencBrcInitDmem->INIT_SlidingWindowMaxRateRatio_U8 = (uint8_t)((uint64_t)avcSeqParams->MaxBitRatePerSlidingWindow * 100 / avcSeqParams->TargetBitRate);
+        }
+        else
+        {
+            hucVdencBrcInitDmem->INIT_SlidingWindowSize_U8         = (uint8_t)(framesFieldsPer100Sec / 100);
+            hucVdencBrcInitDmem->INIT_SlidingWindowMaxRateRatio_U8 = 120;
+        }
     }
 
     MOS_SecureMemcpy(hucVdencBrcInitDmem->INIT_EstRateThreshP0_U8, 7 * sizeof(uint8_t),
@@ -519,7 +545,7 @@ MOS_STATUS AvcEncodeBRC::SetDmemForInit(void *params)
     if (((avcSeqParams->TargetUsage & 0x07) == TARGETUSAGE_BEST_SPEED) &&
         (avcSeqParams->FrameWidth >= setting->singlePassMinFrameWidth) &&
         (avcSeqParams->FrameHeight >= setting->singlePassMinFrameHeight) &&
-        (avcSeqParams->FramesPer100Sec >= setting->singlePassMinFramePer100s))
+        (framesFieldsPer100Sec >= setting->singlePassMinFramePer100s))
     {
         hucVdencBrcInitDmem->INIT_SinglePassOnly = true;
     }
@@ -628,6 +654,8 @@ MOS_STATUS AvcEncodeBRC::SetDmemForUpdate(void *params, uint16_t currPass, bool
     hucVdencBrcUpdateDmem->UPD_PAKPassNum_U8 = (uint8_t)currPass;
     hucVdencBrcUpdateDmem->UPD_MaxNumPass_U8 = m_featureManager->GetNumPass();
 
+    hucVdencBrcUpdateDmem->UPD_AdaptiveTUEnabled = avcPicParams->AdaptiveTUEnabled;
+
     uint32_t numP = 0;
     if (avcSeqParams->GopRefDist && (avcSeqParams->GopPicSize > 0))
     {
@@ -696,7 +724,7 @@ MOS_STATUS AvcEncodeBRC::SetDmemForUpdate(void *params, uint16_t currPass, bool
         }
     }
 
-    hucVdencBrcUpdateDmem->UPD_SLBB_Size_U16 = (uint16_t)m_hwInterface->m_vdencBrcImgStateBufferSize;
+    hucVdencBrcUpdateDmem->UPD_SLBB_Size_U16 = (uint16_t)MOS_ALIGN_CEIL(m_hwInterface->m_vdencBrcImgStateBufferSize, CODECHAL_CACHELINE_SIZE);
 
     hucVdencBrcUpdateDmem->UPD_WidthInMB_U16  = m_basicFeature->m_picWidthInMb;
     hucVdencBrcUpdateDmem->UPD_HeightInMB_U16 = m_basicFeature->m_picHeightInMb;
@@ -1126,7 +1154,7 @@ MOS_STATUS AvcEncodeBRC::FreeBrcResources()
     return eStatus;
 }
 
-int32_t AvcEncodeBRC::ComputeBRCInitQP()
+int32_t AvcEncodeBRC::ComputeBRCInitQP(uint16_t framesFieldsPer100Sec)
 {
     ENCODE_FUNC_CALL();
 
@@ -1138,10 +1166,10 @@ int32_t AvcEncodeBRC::ComputeBRCInitQP()
 
     // InitQPIP calculation
     frameSize = ((m_basicFeature->m_frameWidth * m_basicFeature->m_frameHeight * 3) >> 1);
-    QP        = (int32_t)(1. / 1.2 * pow(10.0, (log10(frameSize * 2. / 3. * ((float)seqParams->FramesPer100Sec) / ((float)(seqParams->TargetBitRate) * 100)) - x0) * (y1 - y0) / (x1 - x0) + y0) + 0.5);
+    QP        = (int32_t)(1. / 1.2 * pow(10.0, (log10(frameSize * 2. / 3. * ((float)framesFieldsPer100Sec) / ((float)(seqParams->TargetBitRate) * 100)) - x0) * (y1 - y0) / (x1 - x0) + y0) + 0.5);
     QP += 2;
     //add additional change based on buffer size. It is especially useful for low delay
-    deltaQ = (int32_t)(9 - (seqParams->VBVBufferSizeInBit * ((float)seqParams->FramesPer100Sec) / ((float)(seqParams->TargetBitRate) * 100)));
+    deltaQ = (int32_t)(9 - (seqParams->VBVBufferSizeInBit * ((float)framesFieldsPer100Sec) / ((float)(seqParams->TargetBitRate) * 100)));
     QP += deltaQ < 0 ? 0 : deltaQ;
     QP = CodecHal_Clip3(ENCODE_AVC_BRC_MIN_QP, CODECHAL_ENCODE_AVC_MAX_SLICE_QP, QP);
     QP--;
